@@ -14,4 +14,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with lazr.lifecycle.  If not, see <http://www.gnu.org/licenses/>.
 
-__version__ = '0.1'
+import pkg_resources
+__version__ = pkg_resources.resource_string(
+    "lazr.lifecycle", "version.txt").strip()
